@@ -62,7 +62,8 @@ PLAY_CODE_ORDERED_DICT = OrderedDict([
 
 NO_HIT_CODE_LIST = ['K', 'ꓘ', 'BB', 'IBB']
 
-BASE_PLUS_ONE_DICT = {'1B': '2nd',
+BASE_PLUS_ONE_DICT = {'': '1st',
+                      '1B': '2nd',
                       '2B': '3rd',
                       '3B': 'home'}
 
@@ -341,6 +342,16 @@ class Team:
         self.player_name_dict[''.join(player.full_name().split())] = player
         self.player_last_name_dict[player.first_name[0] + last_name] = player
 
+        if '-' in last_name:
+            last_half_name = last_name.split('-')[1]
+            self.player_name_dict[
+                '{}{}'.format(player.first_name, last_half_name)
+            ] = player
+
+            self.player_last_name_dict[
+                player.first_name[0] + last_half_name
+            ] = player
+
     def __contains__(self, player_key):
         return bool(self.find_player(player_key))
 
@@ -672,11 +683,6 @@ class PlateAppearance:
                 defense_code_order.append(
                     str(POSITION_CODE_DICT[defense_position])
                 )
-            else:
-                if defense_position.strip(' .') not in ['1st', '2nd', '3rd']:
-                    raise ValueError(
-                        '{} not in position code dict'.format(defense_position)
-                    )
 
         return defense_code_order
 
