@@ -193,6 +193,42 @@ HTML_INDEX_PAGE = (
     '<option {year_list[2012]} value="2012">2012</option>'
     '<option {year_list[2011]} value="2011">2011</option>'
     '<option {year_list[2010]} value="2010">2010</option>'
+    '<option {year_list[2009]} value="2009">2009</option>'
+    '<option {year_list[2008]} value="2008">2008</option>'
+    '<option {year_list[2007]} value="2007">2007</option>'
+    '<option {year_list[2006]} value="2006">2006</option>'
+    '<option {year_list[2005]} value="2005">2005</option>'
+    '<option {year_list[2004]} value="2004">2004</option>'
+    '<option {year_list[2003]} value="2003">2003</option>'
+    '<option {year_list[2002]} value="2002">2002</option>'
+    '<option {year_list[2001]} value="2001">2001</option>'
+    '<option {year_list[2000]} value="2000">2000</option>'
+    '<option {year_list[1999]} value="1999">1999</option>'
+    '<option {year_list[1998]} value="1998">1998</option>'
+    '<option {year_list[1997]} value="1997">1997</option>'
+    '<option {year_list[1996]} value="1996">1996</option>'
+    '<option {year_list[1995]} value="1995">1995</option>'
+    '<option {year_list[1994]} value="1994">1994</option>'
+    '<option {year_list[1993]} value="1993">1993</option>'
+    '<option {year_list[1992]} value="1992">1992</option>'
+    '<option {year_list[1991]} value="1991">1991</option>'
+    '<option {year_list[1990]} value="1990">1990</option>'
+    '<option {year_list[1989]} value="1989">1989</option>'
+    '<option {year_list[1988]} value="1988">1988</option>'
+    '<option {year_list[1987]} value="1987">1987</option>'
+    '<option {year_list[1986]} value="1986">1986</option>'
+    '<option {year_list[1985]} value="1985">1985</option>'
+    '<option {year_list[1984]} value="1984">1984</option>'
+    '<option {year_list[1983]} value="1983">1983</option>'
+    '<option {year_list[1982]} value="1982">1982</option>'
+    '<option {year_list[1981]} value="1981">1981</option>'
+    '<option {year_list[1980]} value="1980">1980</option>'
+    '<option {year_list[1979]} value="1979">1979</option>'
+    '<option {year_list[1978]} value="1978">1978</option>'
+    '<option {year_list[1977]} value="1977">1977</option>'
+    '<option {year_list[1976]} value="1976">1976</option>'
+    '<option {year_list[1975]} value="1975">1975</option>'
+    '<option {year_list[1974]} value="1974">1974</option>'
     '</select>'
     '<div class="clickme" onclick="goforwardone()"><i class="arrow right"></i>'
     '</div>'
@@ -763,37 +799,31 @@ def write_svg_from_file_range(start_date_str, end_date_str, input_dir,
                                                 input_dir)
     ]
 
-    game_html_id_tuple_list = []
-    this_year = this_month = this_day = None
-    for tup in filename_output_path_tuple_list:
-        filename_tuple, _ = tup
-        game_id = filename_tuple[0]
-        year_str, month_str, day_str, _, _, _ = game_id.split('-')
+    start_datetime = parse(start_date_str)
+    end_datetime = parse(end_date_str)
+    day_interval = timedelta(days=1)
+    this_datetime = start_datetime
+    while this_datetime <= end_datetime:
+        game_html_id_tuple_list = []
+        for tup in filename_output_path_tuple_list:
+            filename_tuple, _ = tup
+            game_id = filename_tuple[0]
+            year_str, month_str, day_str, _, _, _ = game_id.split('-')
 
-        if not (this_year and this_month and this_day):
-            this_year = year_str
-            this_month = month_str
-            this_day = day_str
+            if (int(year_str) == this_datetime.year and
+                    int(month_str) == this_datetime.month and
+                    int(day_str) == this_datetime.day):
+                write_game_svg_html_from_filename_tuple(tup, write_game_html)
+                game_html_id_tuple_list.append(
+                    get_game_from_filename_tuple(filename_tuple)
+                )
 
-        if not (year_str == this_year and month_str == this_month and
-                day_str == this_day):
-            this_datetime = parse(
-                '{}-{}-{}'.format(this_year, this_month, this_day)
-            )
+        object_html_str = get_object_html_str(game_html_id_tuple_list)
+        write_game_index(object_html_str, this_datetime, output_dir,
+                         write_date_html, False)
 
-            object_html_str = get_object_html_str(game_html_id_tuple_list)
-            write_game_index(object_html_str, this_datetime, output_dir,
-                             write_date_html, False)
-
-            this_year = year_str
-            this_month = month_str
-            this_day = day_str
-            game_html_id_tuple_list = []
-
-        write_game_svg_html_from_filename_tuple(tup, write_game_html)
-        game_html_id_tuple_list.append(
-            get_game_from_filename_tuple(filename_tuple)
-        )
+        game_html_id_tuple_list = []
+        this_datetime += day_interval
 
 def get_filename_list(start_date_str, end_date_str, input_dir):
     filename_list = []
