@@ -146,6 +146,7 @@ PITCH_TYPE_DESCRIPTION = {'Ball': 'B',
                           'Automatic Strike': 'C',
                           'Swinging Strike': 'S',
                           'Strike': 'S',
+                          'Unknown Strike': 'S',
                           'Swinging Pitchout': 'S',
                           'Foul': 'F',
                           'Foul Tip': 'T',
@@ -1206,7 +1207,7 @@ def process_base_appearances(base_2_pa, base_3_pa, home_pa, batter_final_base,
         else:
             raise ValueError('Invalid Base')
     else:
-        raise ValueError('No Final Base')
+        base_svg = ''
 
     return base_svg
 
